import React__default, { useRef, useState, useMemo } from 'react';
import { i as isSameDay } from '../../chunks/bundle-DYBstvIJ.js';
import Icon, { IconTypes, IconColors } from '../../ui/Icon.js';
import PlaceHolder, { PlaceHolderTypes } from '../../ui/PlaceHolder.js';
import { u as useOpenChannelContext } from '../../chunks/bundle-DuxNodq3.js';
import OpenChannelMessage from './OpenChannelMessage.js';
import { MessageProvider } from '../../Message/context.js';
import { u as useHandleOnScrollCallback } from '../../chunks/bundle-tjmSjVLm.js';
import { compareMessagesForGrouping } from '../../Channel/utils/compareMessagesForGrouping.js';
import { u as useSendbird } from '../../chunks/bundle-D7cX9Fjm.js';
import { u as useLocalization } from '../../chunks/bundle-MU-n4WB7.js';
import '../../chunks/bundle-BYR5uV_H.js';
import '../../chunks/bundle-BvGPxdgc.js';
import '../../chunks/bundle-BoCpB627.js';
import '../../chunks/bundle-CoqWx1L6.js';
import '../../chunks/bundle-BKZt9o1F.js';
import '../../ui/Loader.js';
import '../../chunks/bundle-DkXJrVqz.js';
import '../../chunks/bundle-CjtOeKDH.js';
import '../../chunks/bundle-DcJrfmnR.js';
import '../../chunks/bundle-DnyHxqQ0.js';
import '@sendbird/chat';
import '@sendbird/chat/openChannel';
import '../../chunks/bundle-CTtRmLaQ.js';
import '../../chunks/bundle-B83hoJ_j.js';
import '../../chunks/bundle-B5YnH_bZ.js';
import '../../hooks/useModal.js';
import '../../chunks/bundle-Eoom7SNM.js';
import '../../chunks/bundle-BZABTuI8.js';
import 'react-dom';
import '../../chunks/bundle-DgySHYkz.js';
import '../../ui/IconButton.js';
import '../../ui/Button.js';
import '../../chunks/bundle-B7LJP6uD.js';
import '../../chunks/bundle-T8eF3MdZ.js';
import '@sendbird/chat/groupChannel';
import '../../chunks/bundle-Bmdb9pIK.js';
import '../../ui/OpenchannelUserMessage.js';
import '../../chunks/bundle-DCmMZLn8.js';
import '../../ui/ImageRenderer.js';
import '../../chunks/bundle-CwFhwvI0.js';
import '../../ui/SortByRow.js';
import '../../chunks/bundle-CDxHBrmg.js';
import '../../utils/message/getOutgoingMessageState.js';
import '../../chunks/bundle-KRH4HO2b.js';
import '../../ui/UserProfile.js';
import '../../sendbirdSelectors.js';
import '../../chunks/bundle-BIpsQoZM.js';
import '../../chunks/bundle-Dxu9l-xP.js';
import '../../chunks/bundle-BX570l_k.js';
import '../../ui/OpenChannelAdminMessage.js';
import '../../ui/OpenchannelOGMessage.js';
import '../../ui/LinkLabel.js';
import '../../chunks/bundle-DjDbKets.js';
import '../../chunks/bundle-Cx0ij_p6.js';
import '../../ui/MentionLabel.js';
import '../../ui/OpenchannelThumbnailMessage.js';
import '../../ui/OpenchannelFileMessage.js';
import '../../ui/TextButton.js';
import '../../chunks/bundle-Bpv5h56D.js';
import '../../ui/DateSeparator.js';
import '../../ui/MessageInput.js';
import '../../chunks/bundle-Cx8h9ZUu.js';
import '../../chunks/bundle-C5Ih9B7Z.js';
import '../../chunks/bundle-CUG8aQUl.js';
import 'dompurify';
import '../../chunks/bundle-BBzNJkTC.js';
import '../../chunks/bundle-BntU6xha.js';
import '../../chunks/bundle-BTRsBhSP.js';
import '../../ui/FileViewer.js';
import '../../chunks/bundle-DOwPISeS.js';
import '@sendbird/uikit-tools';
import '../../chunks/bundle-ClP2v0RX.js';
import '../../chunks/bundle-ZNC8CUp_.js';
import '../../chunks/bundle-BID6Oznq.js';
import '@sendbird/chat/message';

function OpenChannelMessageList(props, ref) {
    var _a = useOpenChannelContext(), _b = _a.isMessageGroupingEnabled, isMessageGroupingEnabled = _b === void 0 ? true : _b, allMessages = _a.allMessages, hasMore = _a.hasMore, onScroll = _a.onScroll;
    var state = useSendbird().state;
    var stringSet = useLocalization().stringSet;
    var userId = state.config.userId;
    var localRef = useRef(null);
    var scrollRef = ref || localRef;
    var _c = useState(false), showScrollDownButton = _c[0], setShowScrollDownButton = _c[1];
    var scrollToBottom = function () {
        if (scrollRef && 'current' in scrollRef && scrollRef.current) {
            scrollRef.current.scrollTo(0, scrollRef.current.scrollHeight);
            setShowScrollDownButton(false);
        }
    };
    var handleOnScroll = useHandleOnScrollCallback({
        setShowScrollDownButton: setShowScrollDownButton,
        hasMore: hasMore,
        onScroll: onScroll,
        scrollRef: scrollRef,
    });
    var memoizedMessageList = useMemo(function () {
        var _a;
        if (allMessages.length > 0) {
            return (allMessages.map(function (message, index) {
                var _a;
                var previousMessage = allMessages[index - 1];
                var nextMessage = allMessages[index - 1];
                var previousMessageCreatedAt = previousMessage && previousMessage.createdAt;
                var currentCreatedAt = message === null || message === void 0 ? void 0 : message.createdAt;
                // https://stackoverflow.com/a/41855608
                var hasSeparator = !(previousMessageCreatedAt && (isSameDay(currentCreatedAt, previousMessageCreatedAt)));
                var _b = isMessageGroupingEnabled
                    ? compareMessagesForGrouping(previousMessage, message, nextMessage, stringSet)
                    : [false, false], chainTop = _b[0], chainBottom = _b[1];
                var isByMe = ((_a = message === null || message === void 0 ? void 0 : message.sender) === null || _a === void 0 ? void 0 : _a.userId) === userId;
                var key = (message === null || message === void 0 ? void 0 : message.messageId) || (message === null || message === void 0 ? void 0 : message.reqId);
                return (React__default.createElement(MessageProvider, { message: message, isByMe: isByMe, key: key },
                    React__default.createElement(OpenChannelMessage, { message: message, chainTop: chainTop, chainBottom: chainBottom, hasSeparator: hasSeparator, renderMessage: props === null || props === void 0 ? void 0 : props.renderMessage })));
            }));
        }
        return (((_a = props === null || props === void 0 ? void 0 : props.renderPlaceHolderEmptyList) === null || _a === void 0 ? void 0 : _a.call(props)) || (React__default.createElement(PlaceHolder, { className: "sendbird-openchannel-conversation-scroll__container__place-holder", type: PlaceHolderTypes.NO_MESSAGES })));
    }, [allMessages]);
    return (React__default.createElement("div", { className: "sendbird-openchannel-conversation-scroll" },
        React__default.createElement("div", { className: "sendbird-openchannel-conversation-scroll__container" },
            React__default.createElement("div", { className: "sendbird-openchannel-conversation-scroll__container__padding" }),
            React__default.createElement("div", { className: [
                    'sendbird-openchannel-conversation-scroll__container__item-container',
                    (allMessages.length > 0) ? '' : 'no-messages',
                ].join(' '), onScroll: handleOnScroll, ref: scrollRef }, memoizedMessageList)),
        showScrollDownButton && (React__default.createElement("div", { className: "sendbird-openchannel-conversation-scroll__container__scroll-bottom-button", onClick: scrollToBottom, onKeyDown: scrollToBottom, tabIndex: 0, role: "button" },
            React__default.createElement(Icon, { width: "24px", height: "24px", type: IconTypes.CHEVRON_DOWN, fillColor: IconColors.CONTENT })))));
}
var OpenChannelMessageList$1 = React__default.forwardRef(OpenChannelMessageList);

export { OpenChannelMessageList$1 as default };
//# sourceMappingURL=OpenChannelMessageList.js.map
